@@ -5,6 +5,7 @@ import getpass
 import json
 import os
 import platform
+import shutil
 
 import site
 import sys
@@ -25,14 +26,14 @@ from aniachi import stringUtils, timeUtils
 
 class Welcome:
 
-    __version__=302
+    __version__=.322
 
 
 
     @staticmethod
     def screen_resolution():
 
-        return ('Not implemented yet....')
+        return shutil.get_terminal_size()
 
 
 
@@ -187,7 +188,7 @@ class Welcome:
 #/_/    \____/_/ |_/\____/
 #
     @staticmethod
-    def get_fetchdata(elapsed=timeUtils.elapsedtime(),format='json'):
+    def get_fetchdata(elapsed=timeUtils.elapsedtime(),format='dict'):
         d = dict()
         d['pip version']=pip.__version__
         d['site-package']=site.getsitepackages()
@@ -232,6 +233,8 @@ class Welcome:
 
         if format == 'json':
             return json.dumps(d)
+        elif format=='dict':
+            return d
         else:
             return d
 
@@ -291,13 +294,13 @@ class Welcome:
 
 if __name__ == '__main__':
 
+    # print('*'*30)
+    # Welcome.print_libs_version(libs=['dicttoxml','visualise-spacy-tree','wasabi','numpy'])
+    # print('*'*30)
+    # Welcome.print_welcome()
+    # Welcome.get_installed_distributions_as_dict()
     print('*'*30)
-    Welcome.print_libs_version(libs=['dicttoxml','visualise-spacy-tree','wasabi','numpy'])
-    print('*'*30)
-    Welcome.print_welcome()
-    Welcome.get_installed_distributions_as_dict()
-    print('*'*30)
-    pprint(Welcome.get_fetchdata(format=''))
+    pprint(Welcome.get_fetchdata())
 
 
 
